##  Using SAP LeanIX Architecture and Road Map Planning for Obsolescence Risk Management
Use initiative fact sheets and predefined transformation templates to plan and execute risk remediation initiatives in SAP LeanIX Architecture and Road Map Planning. Use Intiative fact sheets to outline the project and, if needed, break it down into sub-projects organized using the wave approach. This phased approach is helpful for implementing remediation actions based on priorities.
In the project fact sheets, detail how a project will affect the technical landscape and obsolete IT components using predefined transformation templates such as <Change Application Technology>, <Change Interface Technology>, and <Decommission Application>, among others. To learn how to use transformation templates, see [Transformations](https://help.sap.com/docs/leanix/ea/transformations?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to define and manage Transformations in the Initiative Fact Sheet.").
The impacts of these defined transformation items can then be visualized and monitored using the initiative roadmap report, as illustrated below. The report drilled down to IT components, and with the Lifecycle view applied, provides a temporal view of how the impacts of the transformation items will progress. It indicates when specific successors are planned to replace outdated end-of-life IT components, when certain IT components are planned to phase out, and more.
![Remediation Roadmap Illustrating the Wave Approach and Impacts at the IT Component Level](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274714d37a4410149e94ec4b21b143c2_LowRes.png)
Remediation Roadmap Illustrating the Wave Approach and Impacts at the IT Component Level
You can include the broader organizational context by considering organizations or business units in the project timeline for the impact assessment. This ensures a more coordinated and effective roll-out of new technology across the organization or business units.
![Remediation plan clustered by Organization for Organizational Context](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2747fa1e7a441014ad84d20dd3a80146_LowRes.png)
Remediation plan clustered by Organization for Organizational Context
Project the impacts of remediation initiatives on to the timeline of reports to view the future state of your landscape. The following example shows the prospective states of the IT component landscape with respect to accepted and addressed risks. In the IT component landscape report, select the initiative fact sheet to be projected on to the timeline, apply Applications: Obsolescence Risk Status view, and use filters to refine or narrow down to IT components affected by the project.
![Remediation Impact - Prospective States of IT Component Landscape With Respect to Accepted and Addressed Risks](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2754fe6c7a441014a8f9cc050c1c9f82_LowRes.png)
Remediation Impact - Prospective States of IT Component Landscape With Respect to Accepted and Addressed Risks
